from search_engine_parser import GoogleSearch
import re
import requests
import random


class DevTo:
    def __init__(self, title, tags):
        self.title = title
        self.tags = tags

    def get_api_key(self):
        """
        get random api key from api keys of rss2json.com
        :return: string
        """
        api_keys = [
            "2rk1eg4sexdnp5umrwtwbtwd2insqvgzvejooqrn",
            "yit6ytfcs3ziawdgasfd3bgkbf4tef1m2nzdxvnz",
            "mpawymyrc6derrwmgodowfsaabtuoes4iiwintd7",
        ]
        return random.choice(api_keys)

    def google(self, query):
        search_args = (query, 1)
        gsearch = GoogleSearch()
        gresults = gsearch.search(*search_args)
        return gresults["links"]

    def get_valid_urls(self, links):
        """
        filter out invalid urls
        """
        validUrls = []
        for i in links:
            if "dev.to" in i:
                uriTrimmed = re.match(r"^.*?\&sa=", i[29:]).group(0)
                ur = uriTrimmed.replace("&sa=", "")
                validUrls.append(ur)
        return validUrls

    def get_valid_sets(self, validUrls):
        """
        extract valid usernames and tags from valid dev.to urls
        """
        validSets = []
        for url in validUrls:
            try:
                vset = {}
                username = re.search(r"https://dev.to/([^/?]+)", url).group(1)
                tag = re.search(r"https://dev.to/([^/?]+)/([^/?]+)", url).group(2)
                vset["username"] = username
                vset["tag"] = tag
                validSets.append(vset)
            except Exception as e:
                print(e)
                continue
        return validSets

    def get_blogs(self, username, tag):
        """
        get the contents of the dev.to article
        """
        blog = {}
        try:
            response = requests.get(
                f"https://api.rss2json.com/v1/api.json?rss_url=https%3A%2F%2Fdev.to%2Ffeed%2F{username}&api_key={self.get_api_key()}"
            )
            if response.status_code == 200:
                res = response.json()
                for item in res["items"]:
                    if tag in item["link"]:
                        blog = item
        except Exception as e:
            print(e)
        return blog

    def get_dev_articles(self):
        """
        Search google for dev.to articles
        return a list of urls
        filter out invalid urls
        get content of the valid urls
        return the content of valid dev.to articles
        """
        try:
            links = self.google(f"site:dev.to {self.title} after:2020-01-01")
            validUrls = self.get_valid_urls(links)
            validSets = self.get_valid_sets(validUrls)
            blogs = []
            for validset in validSets:
                blog = self.get_blogs(validset["username"], validset["tag"])
                if bool(blog):
                    blogs.append(blog)
            return {"blogs": blogs, "resources": validUrls}
        except Exception as e:
            print(e)
            return {"blogs": [], "resources": []}