import {
  Box,
  Button,
  Dialog,
  DialogActions,
  DialogContent,
  DialogContentText,
  DialogTitle,
  Typography
} from '@material-ui/core'
import React, { useContext, useState } from 'react'
import { disconnectTelegram } from '../../../actions/telegram'
import { AuthContext } from '../../../store/auth'

const TelegramDisconnect = ({ username, setActiveStep, setSnackbar }) => {
  const [open, setOpen] = useState(false)
  const { authState, setAuthState } = useContext(AuthContext)
  const disconnect = async () => {
    setOpen(() => false)
    const isDisconnected = await disconnectTelegram(username)

    if (isDisconnected) {
      authState.userInfo.isTelegramConnected = false
      setAuthState(authState)
      setActiveStep(0)
      setSnackbar({
        show: true,
        message: 'Telegram account disconnected',
        severity: 'success'
      })
    }
  }

  return (
    <Box sx={{ mt: '10px' }}>
      <Typography variant="h5" align="center">
        All done! You are now connected with the Telegram bot.
      </Typography>
      <Box
        style={{ background: '#fff' }}
        display="flex"
        flexDirection="column"
        margin="auto"
        padding="20px 10px"
      >
        <Typography variant="h6" align="center">
          You can disconnect the bot from your account by clicking the button
          below.
        </Typography>
        <Button
          variant="outlined"
          color="error"
          onClick={() => setOpen(!open)}
          style={{ margin: 'auto', background: '#FF1744', color: '#fff' }}
        >
          Disconnect
        </Button>
        <Dialog open={open} onClose={() => setOpen(false)}>
          <DialogTitle>Disconnect Telegram Bot</DialogTitle>
          <DialogContent>
            <DialogContentText id="alert-dialog-description" color="#000">
              By disconnecting the bot, you will no longer be able to use the
              bot to send messages to your account. (Ask questions) In order to
              reconnect the bot, you will need to follow the steps again.
            </DialogContentText>
            <img
              src="https://i.imgur.com/ccH89kQ.jpg"
              width="80%"
              style={{ display: 'block', margin: 'auto' }}
            />
          </DialogContent>
          <DialogActions>
            <Button
              variant="outlined"
              color="inherit"
              onClick={() => setOpen(false)}
            >
              Cancel
            </Button>
            <Button
              variant="outlined"
              onClick={disconnect}
              autoFocus
              style={{ border: '1px solid #FF1744', color: '#FF1744' }}
            >
              Disconnect
            </Button>
          </DialogActions>
        </Dialog>
      </Box>
    </Box>
  )
}

export default TelegramDisconnect
